@@ -77,5 +77,12 @@ dotest "-c 4 -w 4 00 964213" "2"
 dotest "-c 4 -w 4 -d 6 00 964213" "2"
 dotest "-c 4 -w 4 -d 7 00 964213" "2" fail
 dotest "-c 4 -d 7 00 964213" "2" fail
+dotest "--totp 3132333435363738393031323334353637383930 -N @59 -d8" "94287082"
+dotest "--totp 3132333435363738393031323334353637383930 -N @1111111109 -d8" "07081804"
+dotest "--totp 3132333435363738393031323334353637383930 -N @1111111111 -d8" "14050471"
+dotest "--totp 3132333435363738393031323334353637383930 -N @1234567890 -d8" "89005924"
+dotest "--totp 3132333435363738393031323334353637383930 -N @2000000000 -d8" "69279037"
+dotest "--totp 00 --time-step-size=45m --start-time=now --now=now" "328482"
+dotest "--totp 00 --time-step-size=1m --start-time=now --now=hour -d7" "4511481"
 
 exit 0
